@@ -34,9 +34,11 @@
 
 #include "xf86.h"
 #include "xf86Pci.h"
-#include "xf86PciInfo.h"
 #include "xf86RamDac.h"
+#ifdef HAVE_XAA_H
 #include "xaa.h"
+#endif
+#include "xf86fbman.h"
 #include "vbe.h"
 #include "vgaHW.h"
 
@@ -45,6 +47,25 @@
 #include <X11/extensions/Xv.h>
 #include "fourcc.h"
 
+#include "compat-api.h"
+
+
+#define PCI_VENDOR_S3			0x5333
+
+#define PCI_CHIP_PLATO			0x0551
+#define PCI_CHIP_TRIO			0x8811
+#define PCI_CHIP_AURORA64VP		0x8812
+#define PCI_CHIP_TRIO64UVP		0x8814
+#define PCI_CHIP_868			0x8880
+#define PCI_CHIP_928			0x88B0
+#define PCI_CHIP_864_0			0x88C0
+#define PCI_CHIP_864_1			0x88C1
+#define PCI_CHIP_964_0			0x88D0
+#define PCI_CHIP_964_1			0x88D1
+#define PCI_CHIP_968			0x88F0
+#define PCI_CHIP_TRIO64V2_DXGX	0x8901
+#define PCI_CHIP_PLATO_PX		0x8902
+
 
 typedef struct _S3RegRec {
 	unsigned char	cr31, cr32, cr33, cr34, cr3a, cr3b, cr3c;
@@ -110,7 +131,9 @@ typedef struct _S3Rec {
 	Bool			PCIRetry;
 	Bool			ColorExpandBug;
 
+#ifdef HAVE_XAA_H
         XAAInfoRecPtr           pXAA;
+#endif
 	xf86CursorInfoPtr	pCurs;
 	xf86Int10InfoPtr	pInt10;
         XF86VideoAdaptorPtr     adaptor;
@@ -156,7 +179,7 @@ typedef struct _S3Rec {
 					       int *indicies, LOCO *colors,
 					       VisualPtr pVisual);
 
-        Bool                    (*CloseScreen)(int, ScreenPtr);
+	Bool                    (*CloseScreen)(CLOSE_SCREEN_ARGS_DECL);
 
 	unsigned char		*imageBuffer;
 	int			imageWidth;
@@ -167,7 +190,7 @@ typedef struct _S3Rec {
 	int                     rotate;
 	unsigned char           * ShadowPtr;
 	int                     ShadowPitch;
-	void	                (*PointerMoved)(int index, int x, int y);
+	void	                (*PointerMoved)(SCRN_ARG_TYPE arg, int x, int y);
     
 } S3Rec, *S3Ptr;
 
@@ -193,7 +216,7 @@ Bool S3AccelInit(ScreenPtr pScreen);
 Bool S3AccelInitNewMMIO(ScreenPtr pScreen);
 Bool S3AccelInitPIO(ScreenPtr pScreen);
 Bool S3DGAInit(ScreenPtr pScreen);
-Bool S3SwitchMode(int scrnIndex, DisplayModePtr mode, int flags);
+Bool S3SwitchMode(SWITCH_MODE_ARGS_DECL);
 int S3GetRefClock(ScrnInfoPtr pScrn);
 
 void S3InitVideo(ScreenPtr pScreen);
@@ -231,7 +254,7 @@ void S3OutTiIndReg(ScrnInfoPtr pScrn, CARD32 reg, unsigned char mask,
 Bool S3_CursorInit(ScreenPtr pScreen);
 
 /* in s3_shadow.c */
-void S3PointerMoved(int index, int x, int y);
+void S3PointerMoved(SCRN_ARG_TYPE arg, int x, int y);
 void S3RefreshArea(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 void S3RefreshArea8(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 void S3RefreshArea16(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
@@ -243,9 +266,6 @@ void S3RefreshArea32(ScrnInfoPtr pScrn, int num, BoxPtr pbox);
 #define	TI3025_RAMDAC	0x3025
 #define	TI3020_RAMDAC	0x3020
 
-#define BIOS_BSIZE	1024
-#define	BIOS_BASE	0xc0000
-
 /*
  * Chip...Sets...
  */
